@@ -45,3 +45,20 @@ def generate_214_l0_fits_frame(
     del translated_header["COMMENT"]
     hdu = fits.PrimaryHDU(data=data, header=fits.Header(translated_header))
     return fits.HDUList([hdu])
+
+
+@pytest.fixture(scope="session")
+def parameter_file_object_key() -> str:
+    return "random.fits"
+
+
+@pytest.fixture(scope="session")
+def random_parameter_hdulist() -> (fits.HDUList, float, float, float):
+    rng = np.random.default_rng()
+    mu, std = 10.0, 2.0
+    const = 5.0
+    rand_data = rng.normal(mu, std, size=(100, 100))
+    const_data = np.ones((10, 10)) * const
+    hdul = fits.HDUList([fits.PrimaryHDU(rand_data), fits.ImageHDU(const_data)])
+
+    return hdul, mu, std, const
